==> opensearch-dashboards-2.10.0.tgz: opensearch-dashboards/src/plugins/discover/common/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SORT_DEFAULT_ORDER_SETTING = exports.SEARCH_ON_PAGE_LOAD_SETTING = exports.SAMPLE_SIZE_SETTING = exports.PLUGIN_ID = exports.NEW_DISCOVER_APP = exports.MODIFY_COLUMNS_ON_SWITCH = exports.FIELDS_LIMIT_SETTING = exports.DOC_HIDE_TIME_COLUMN_SETTING = exports.DEFAULT_COLUMNS_SETTING = exports.CONTEXT_TIE_BREAKER_FIELDS_SETTING = exports.CONTEXT_STEP_SETTING = exports.CONTEXT_DEFAULT_SIZE_SETTING = exports.AGGS_TERMS_SIZE_SETTING = void 0;

/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
const PLUGIN_ID = 'discover';
exports.PLUGIN_ID = PLUGIN_ID;
const NEW_DISCOVER_APP = 'discover:v2';
exports.NEW_DISCOVER_APP = NEW_DISCOVER_APP;
const DEFAULT_COLUMNS_SETTING = 'defaultColumns';
exports.DEFAULT_COLUMNS_SETTING = DEFAULT_COLUMNS_SETTING;
const SAMPLE_SIZE_SETTING = 'discover:sampleSize';
exports.SAMPLE_SIZE_SETTING = SAMPLE_SIZE_SETTING;
const AGGS_TERMS_SIZE_SETTING = 'discover:aggs:terms:size';
exports.AGGS_TERMS_SIZE_SETTING = AGGS_TERMS_SIZE_SETTING;
const SORT_DEFAULT_ORDER_SETTING = 'discover:sort:defaultOrder';
exports.SORT_DEFAULT_ORDER_SETTING = SORT_DEFAULT_ORDER_SETTING;
const SEARCH_ON_PAGE_LOAD_SETTING = 'discover:searchOnPageLoad';
exports.SEARCH_ON_PAGE_LOAD_SETTING = SEARCH_ON_PAGE_LOAD_SETTING;
const DOC_HIDE_TIME_COLUMN_SETTING = 'doc_table:hideTimeColumn';
exports.DOC_HIDE_TIME_COLUMN_SETTING = DOC_HIDE_TIME_COLUMN_SETTING;
const FIELDS_LIMIT_SETTING = 'fields:popularLimit';
exports.FIELDS_LIMIT_SETTING = FIELDS_LIMIT_SETTING;
const CONTEXT_DEFAULT_SIZE_SETTING = 'context:defaultSize';
exports.CONTEXT_DEFAULT_SIZE_SETTING = CONTEXT_DEFAULT_SIZE_SETTING;
const CONTEXT_STEP_SETTING = 'context:step';
exports.CONTEXT_STEP_SETTING = CONTEXT_STEP_SETTING;
const CONTEXT_TIE_BREAKER_FIELDS_SETTING = 'context:tieBreakerFields';
exports.CONTEXT_TIE_BREAKER_FIELDS_SETTING = CONTEXT_TIE_BREAKER_FIELDS_SETTING;
const MODIFY_COLUMNS_ON_SWITCH = 'discover:modifyColumnsOnSwitch';
exports.MODIFY_COLUMNS_ON_SWITCH = MODIFY_COLUMNS_ON_SWITCH;

==> opensearch-dashboards-2.11.1.tgz: opensearch-dashboards/src/plugins/discover/common/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SORT_DEFAULT_ORDER_SETTING = exports.SEARCH_ON_PAGE_LOAD_SETTING = exports.SAMPLE_SIZE_SETTING = exports.PLUGIN_ID = exports.MODIFY_COLUMNS_ON_SWITCH = exports.FIELDS_LIMIT_SETTING = exports.DOC_HIDE_TIME_COLUMN_SETTING = exports.DEFAULT_COLUMNS_SETTING = exports.CONTEXT_TIE_BREAKER_FIELDS_SETTING = exports.CONTEXT_STEP_SETTING = exports.CONTEXT_DEFAULT_SIZE_SETTING = exports.AGGS_TERMS_SIZE_SETTING = void 0;

/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
const PLUGIN_ID = 'discover';
exports.PLUGIN_ID = PLUGIN_ID;
const DEFAULT_COLUMNS_SETTING = 'defaultColumns';
exports.DEFAULT_COLUMNS_SETTING = DEFAULT_COLUMNS_SETTING;
const SAMPLE_SIZE_SETTING = 'discover:sampleSize';
exports.SAMPLE_SIZE_SETTING = SAMPLE_SIZE_SETTING;
const AGGS_TERMS_SIZE_SETTING = 'discover:aggs:terms:size';
exports.AGGS_TERMS_SIZE_SETTING = AGGS_TERMS_SIZE_SETTING;
const SORT_DEFAULT_ORDER_SETTING = 'discover:sort:defaultOrder';
exports.SORT_DEFAULT_ORDER_SETTING = SORT_DEFAULT_ORDER_SETTING;
const SEARCH_ON_PAGE_LOAD_SETTING = 'discover:searchOnPageLoad';
exports.SEARCH_ON_PAGE_LOAD_SETTING = SEARCH_ON_PAGE_LOAD_SETTING;
const DOC_HIDE_TIME_COLUMN_SETTING = 'doc_table:hideTimeColumn';
exports.DOC_HIDE_TIME_COLUMN_SETTING = DOC_HIDE_TIME_COLUMN_SETTING;
const FIELDS_LIMIT_SETTING = 'fields:popularLimit';
exports.FIELDS_LIMIT_SETTING = FIELDS_LIMIT_SETTING;
const CONTEXT_DEFAULT_SIZE_SETTING = 'context:defaultSize';
exports.CONTEXT_DEFAULT_SIZE_SETTING = CONTEXT_DEFAULT_SIZE_SETTING;
const CONTEXT_STEP_SETTING = 'context:step';
exports.CONTEXT_STEP_SETTING = CONTEXT_STEP_SETTING;
const CONTEXT_TIE_BREAKER_FIELDS_SETTING = 'context:tieBreakerFields';
exports.CONTEXT_TIE_BREAKER_FIELDS_SETTING = CONTEXT_TIE_BREAKER_FIELDS_SETTING;
const MODIFY_COLUMNS_ON_SWITCH = 'discover:modifyColumnsOnSwitch';
exports.MODIFY_COLUMNS_ON_SWITCH = MODIFY_COLUMNS_ON_SWITCH;
